| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.DFAReporting.EventTags.Insert
Description
Inserts a new event tag.
See: DCM/DFA Reporting And Trafficking API Reference for dfareporting.eventTags.insert.
- type EventTagsInsertResource = "dfareporting" :> ("v2.7" :> ("userprofiles" :> (Capture "profileId" (Textual Int64) :> ("eventTags" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] EventTag :> Post '[JSON] EventTag))))))
- eventTagsInsert :: Int64 -> EventTag -> EventTagsInsert
- data EventTagsInsert
- etiProFileId :: Lens' EventTagsInsert Int64
- etiPayload :: Lens' EventTagsInsert EventTag
REST Resource
type EventTagsInsertResource = "dfareporting" :> ("v2.7" :> ("userprofiles" :> (Capture "profileId" (Textual Int64) :> ("eventTags" :> (QueryParam "alt" AltJSON :> (ReqBody '[JSON] EventTag :> Post '[JSON] EventTag)))))) Source #
A resource alias for dfareporting.eventTags.insert method which the
EventTagsInsert request conforms to.
Creating a Request
Arguments
| :: Int64 | |
| -> EventTag | |
| -> EventTagsInsert |
Creates a value of EventTagsInsert with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data EventTagsInsert Source #
Inserts a new event tag.
See: eventTagsInsert smart constructor.
Instances
Request Lenses
etiProFileId :: Lens' EventTagsInsert Int64 Source #
User profile ID associated with this request.
etiPayload :: Lens' EventTagsInsert EventTag Source #
Multipart request metadata.