| Copyright | (c) 2015-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.Google.Resource.DFAReporting.PlatformTypes.List
Description
Retrieves a list of platform types.
See: DCM/DFA Reporting And Trafficking API Reference for dfareporting.platformTypes.list.
- type PlatformTypesListResource = "dfareporting" :> ("v2.7" :> ("userprofiles" :> (Capture "profileId" (Textual Int64) :> ("platformTypes" :> (QueryParam "alt" AltJSON :> Get '[JSON] PlatformTypesListResponse)))))
- platformTypesList :: Int64 -> PlatformTypesList
- data PlatformTypesList
- ptlProFileId :: Lens' PlatformTypesList Int64
REST Resource
type PlatformTypesListResource = "dfareporting" :> ("v2.7" :> ("userprofiles" :> (Capture "profileId" (Textual Int64) :> ("platformTypes" :> (QueryParam "alt" AltJSON :> Get '[JSON] PlatformTypesListResponse))))) Source #
A resource alias for dfareporting.platformTypes.list method which the
PlatformTypesList request conforms to.
Creating a Request
Arguments
| :: Int64 | |
| -> PlatformTypesList |
Creates a value of PlatformTypesList with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
data PlatformTypesList Source #
Retrieves a list of platform types.
See: platformTypesList smart constructor.
Request Lenses
ptlProFileId :: Lens' PlatformTypesList Int64 Source #
User profile ID associated with this request.